===========================
 REANA - Reusable Analyses
===========================

.. image:: https://img.shields.io/travis/reanahub/reana.svg
   :target: https://travis-ci.org/reanahub/reana

.. image:: https://readthedocs.org/projects/reana/badge/?version=latest
   :target: https://reana.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/coveralls/reanahub/reana.svg
   :target: https://coveralls.io/r/reanahub/reana

.. image:: https://badges.gitter.im/Join%20Chat.svg
   :target: https://gitter.im/reanahub/reana?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

.. image:: https://img.shields.io/github/license/reanahub/reana.svg
   :target: https://github.com/reanahub/reana/blob/master/LICENSE

About
-----

`REANA <http://www.reana.io>`_ is a reusable and reproducible research data
analysis platform. It helps researchers to structure their input data, analysis
code, containerised environments and computational workflows so that the
analysis can be instantiated and run on remote compute clouds.

REANA was born to target the use case of particle physics analyses, but is
applicable to any scientific discipline. The system paves the way towards
reusing and reinterpreting preserved data analyses even several years after the
original publication.

Features
--------

- structure research data analysis in reusable manner
- instantiate computational workflows on remote clouds
- rerun analyses with modified input data, parameters or code
- support for several compute clouds (Kubernetes/OpenStack)
- support for several workflow specifications (CWL, Serial, Yadage)
- support for several shared storage systems (Ceph)
- support for several container technologies (Docker)

Useful links
------------

- `REANA home page <http://www.reana.io/>`_
- `REANA on DockerHub <https://hub.docker.com/u/reanahub/>`_
- `REANA on GitHub <https://github.com/reanahub/>`_
- `REANA on ReadTheDocs <https://reana.readthedocs.io/>`_
- `REANA on Twitter <https://twitter.com/reanahub>`_
